Usage
=====

TODO

Here are the command line options for `evariste`.

.. argparse::
    :module: evariste.main.options
    :func: commandline_parser
    :prog: evariste

TODO Some command line arguments can be set in setup file
